@@ -120,7 +120,11 @@ function fillThreadPaneContextMenu()
   EnableMenuItem("threadPaneContext-labels", (numSelected >= 1));
   EnableMenuItem("threadPaneContext-mark", (numSelected >= 1));
   SetupSaveAsMenuItem("threadPaneContext-saveAs", numSelected, false);
+#ifdef XP_MACOSX
+  SetupPrintPreviewMenuItem("threadPaneContext-printpreview", numSelected, true);
+#else
   SetupPrintPreviewMenuItem("threadPaneContext-printpreview", numSelected, false);
+#endif
   SetupPrintMenuItem("threadPaneContext-print", numSelected, false);
   SetupDeleteMenuItem("threadPaneContext-delete", numSelected, false);
   SetupAddSenderToABMenuItem("threadPaneContext-addSenderToAddressBook", numSelected, false);
@@ -266,6 +270,8 @@ function fillFolderPaneContextMenu()
     return false;
   var numSelected = endIndex.value - startIndex.value + 1;
   var folderResource = GetFolderResource(folderTree, startIndex.value);
+  var folder = GetMsgFolderFromUri(folderResource.Value, false);
+  var isVirtualFolder = folder ? folder.flags & MSG_FOLDER_FLAG_VIRTUAL : false;
 
   var isServer = GetFolderAttribute(folderTree, folderResource, "IsServer") == 'true';
   var serverType = GetFolderAttribute(folderTree, folderResource, "ServerType");
@@ -286,7 +292,7 @@ function fillFolderPaneContextMenu()
   SetupRemoveMenuItem(folderResource, numSelected, isServer, serverType, specialFolder);
   SetupCompactMenuItem(folderResource, numSelected);
 
-  ShowMenuItem("folderPaneContext-copy-location", !isServer);
+  ShowMenuItem("folderPaneContext-copy-location", !isServer && !isVirtualFolder);
   ShowMenuItem("folderPaneContext-emptyTrash", (numSelected <= 1) && (specialFolder == 'Trash'));
   EnableMenuItem("folderPaneContext-emptyTrash", true);
 
@@ -300,8 +306,8 @@ function fillFolderPaneContextMenu()
 
   SetupNewMenuItem(folderResource, numSelected, isServer, serverType, specialFolder);
 
-  ShowMenuItem("folderPaneContext-subscribe", (numSelected <= 1) && canSubscribeToFolder);
-  EnableMenuItem("folderPaneContext-subscribe", true);
+  ShowMenuItem("folderPaneContext-subscribe", (numSelected <= 1) && canSubscribeToFolder && !isVirtualFolder);
+  EnableMenuItem("folderPaneContext-subscribe", !isVirtualFolder);
 
   // XXX: Hack for RSS servers...
   ShowMenuItem("folderPaneContext-rssSubscribe", (numSelected <= 1) && (serverType == "rss"));
@@ -317,11 +323,11 @@ function fillFolderPaneContextMenu()
 
 // End of News folder context menu =======================================
 
-  ShowMenuItem("folderPaneContext-markMailFolderAllRead", (numSelected <= 1) && isMailFolder);
-  EnableMenuItem("folderPaneContext-markMailFolderAllRead", true);
+  ShowMenuItem("folderPaneContext-markMailFolderAllRead", (numSelected <= 1) && isMailFolder && !isVirtualFolder);
+  EnableMenuItem("folderPaneContext-markMailFolderAllRead", !isVirtualFolder);
 
-  ShowMenuItem("folderPaneContext-searchMessages", (numSelected<=1));
-  EnableMenuItem("folderPaneContext-searchMessages", IsCanSearchMessagesEnabled());
+  ShowMenuItem("folderPaneContext-searchMessages", (numSelected<=1) && !isVirtualFolder);
+  EnableMenuItem("folderPaneContext-searchMessages", IsCanSearchMessagesEnabled() && !isVirtualFolder);
 
   return(true);
 }
@@ -330,7 +336,8 @@ function SetupRenameMenuItem(folderResource, numSelected, isServer, serverType,
 {
   var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
   var folderTree = GetFolderTree();
-  var isSpecialFolder = !(specialFolder == "none" || (specialFolder == "Junk" && CanRenameDeleteJunkMail(msgFolder.URI)));
+  var isSpecialFolder = !(specialFolder == "none" || (specialFolder == "Junk" && CanRenameDeleteJunkMail(msgFolder.URI))
+                                                  || (specialFolder == "Virtual") );
   var canRename = GetFolderAttribute(folderTree, folderResource, "CanRename") == "true";
 
   ShowMenuItem("folderPaneContext-rename", (numSelected <= 1) && !isServer && !isSpecialFolder && canRename);
@@ -347,7 +354,8 @@ function SetupRemoveMenuItem(folderResource, numSelected, isServer, serverType,
 {
   var msgFolder = folderResource.QueryInterface(Components.interfaces.nsIMsgFolder);
   var isMail = serverType != 'nntp';
-  var isSpecialFolder = !(specialFolder == "none" || (specialFolder == "Junk" && CanRenameDeleteJunkMail(msgFolder.URI)));
+  var isSpecialFolder = !(specialFolder == "none" || (specialFolder == "Junk" && CanRenameDeleteJunkMail(msgFolder.URI))
+                                                  || (specialFolder == "Virtual") );
   //Can't currently delete Accounts or special folders.
   var showRemove = (numSelected <=1) && (isMail && !isSpecialFolder) && !isServer;
 
@@ -367,9 +375,9 @@ function SetupCompactMenuItem(folderResource, numSelected)
 {
   var folderTree = GetFolderTree();
   var canCompact = GetFolderAttribute(folderTree, folderResource, "CanCompact") == "true";
-  ShowMenuItem("folderPaneContext-compact", (numSelected <=1) && canCompact);
   var folder = GetMsgFolderFromResource(folderResource);
-  EnableMenuItem("folderPaneContext-compact", folder.isCommandEnabled("cmd_compactFolder"));
+  ShowMenuItem("folderPaneContext-compact", (numSelected <=1) && canCompact && !(folder.flags & MSG_FOLDER_FLAG_VIRTUAL));
+  EnableMenuItem("folderPaneContext-compact", folder.isCommandEnabled("cmd_compactFolder") && !(folder.flags & MSG_FOLDER_FLAG_VIRTUAL));
 
   if(canCompact)
   {
@@ -459,7 +467,12 @@ function fillMessagePaneContextMenu()
   SetupLabelsMenuItem("messagePaneContext-labels", numSelected, (numSelected == 0 || hideMailItems));
   SetupMarkMenuItem("messagePaneContext-mark", numSelected, (numSelected == 0 || hideMailItems));
   SetupSaveAsMenuItem("messagePaneContext-saveAs", numSelected, (numSelected == 0 || hideMailItems));
+#ifdef XP_MACOSX
+  SetupPrintPreviewMenuItem("messagePaneContext-printpreview", numSelected, true);
+#else
   SetupPrintPreviewMenuItem("messagePaneContext-printpreview", numSelected, (numSelected == 0 || hideMailItems));
+#endif
+
   SetupPrintMenuItem("messagePaneContext-print", numSelected, (numSelected == 0 || hideMailItems));
   if (numSelected == 0 || hideMailItems)
     ShowMenuItem("messagePaneContext-delete", false)
